diff Gear.lua @ 165:3be9cc6f7d20 v77

Updated for 8.2, initial essence support.
author yellowfive
date Tue, 25 Jun 2019 10:27:20 -0700
parents 35612aee8e15
children d90a740a1d0b
line wrap: on
line diff
--- a/Gear.lua	Tue May 07 10:32:41 2019 -0700
+++ b/Gear.lua	Tue Jun 25 10:27:20 2019 -0700
@@ -223,11 +223,13 @@
 	local gear
 	local spec
 	local setupIndex
+	local essences
 	for i, setup in ipairs(Amr.db.char.GearSetups) do
 		if setup.Id == setupId then
 			setupIndex = i
 			gear = setup.Gear
 			spec = setup.SpecSlot
+			essences = setup.Essences
 			break
 		end
 	end
@@ -311,6 +313,7 @@
 			end
 
 			local isAzerite = optimalItem and C_AzeriteEmpoweredItem.IsAzeriteEmpoweredItemByID(optimalItem.id)
+			local isEssence = essences and optimalItem and optimalItem.id == 158075
 			
 			-- find the item in the player's inventory that best matches what the optimization wants to use
 			local matchItem = Amr:FindMatchingItem(optimalItem, player, usedItems)
@@ -370,7 +373,7 @@
 			-- modifications
 			if optimalItem then
 
 				-- gems or azerite powers
 				local prevSocket = nil
 
 				if isAzerite then
@@ -390,6 +393,8 @@
 							prevSocket = socketBorder
 						end
 					end
+				elseif isEssence then
+					-- TODO: render essence differences
 				else
 					for i = 1, #optimalItem.gemIds do
 						-- we rely on the fact that the gear sets coming back from the site will almost always have all sockets filled,
@@ -370,7 +373,7 @@
 			if optimalItem then
 
-				-- gems or azerite powers
+				-- gems or azerite powers or essences
 				local prevSocket = nil
 